@@ -1,11 +1,9 @@
 package Data::DPath;
-# git description: v0.52-2-gd57c0ec
-
 BEGIN {
   $Data::DPath::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: DPath is not XPath!
-$Data::DPath::VERSION = '0.53';
+$Data::DPath::VERSION = '0.55';
 use 5.008;
 use strict;
 use warnings;
@@ -57,6 +55,11 @@ sub match {
         Data::DPath::Path->new(path => $path_str)->match($data);
 }
 
+sub matchr {
+        my ($class, $data, $path_str) = @_;
+        Data::DPath::Path->new(path => $path_str)->matchr($data);
+}
+
 # ------------------------------------------------------------
 
 1;
@@ -65,7 +68,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -371,6 +374,10 @@ See chapter L<Iterator style|/"Iterator style"> below for details.
 
 Returns an array of all values in C<$data> that match the C<$path>.
 
+=head2 matchr( $data, $path )
+
+Returns an array ref of all values in C<$data> that match the C<$path>.
+
 =head1 OPERATOR
 
 =head2 ~~
@@ -805,7 +812,7 @@ C<< $iterator->value->deref >>.
 The line B<#(2)> is utilizing the internal data structure to find out
 about the actual hash key under which the point is located. (There is
 also an official API to that: C<< $ancestor->first_point->attrs->key >>, 
-but there it's neccessary to check for undefined values before
+but there it's necessary to check for undefined values before
 calling the methods F<attrs> and F<key>, so I went the easy way).
 
 =head1 INTERNAL METHODS
